<template>
  <a-card
    :bordered="false"
    class="card-area"
  >
    <template slot="title">
      <i
        class="action-jeecg actionsite2"
        style="font-size: 18px;"
      />
      工厂
    </template>
    <div
      class="table-operator"
      style="margin-top: 5px"
    >
      <!-- <a-button
        type="primary"
        @click="searchQuery"
        icon="search"
      >查询</a-button>
      <a-button
        @click="searchReset"
        icon="reload"
      >重置</a-button> -->
      <a-button
        @click="handleAddPre"
        type="primary"
        icon="plus"
      >新增</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-button style="margin-left: 8px">
          批量操作
          <a-icon type="down" />
        </a-button>
        <a-menu slot="overlay">
          <a-menu-item @click="batchDel">
            <a-icon type="delete" />删除
          </a-menu-item>
        </a-menu>
      </a-dropdown>
    </div>
    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey="id"
      :columns="columns"
      :rowClassName="tableRowClass"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
      @change="handleTableChange"
    ><!--状态栏个性展示-->
      <span
        class="table-operation"
        slot-scope="text, record"
        slot="action"
      >
        <a
          href="javascript:;"
          @click="handleDetail(record)"
        >详情</a>
        <a-divider type="vertical" />
        <a-dropdown>
          <a class="ant-dropdown-link">
            更多
            <a-icon type="down" />
          </a>
          <a-menu slot="overlay">
            <a-menu-item>
              <a @click="handleEdit(record)">编辑</a>
            </a-menu-item>
            <a-menu-item>
              <a-popconfirm
                title="确定删除吗?"
                @confirm="() => handleDelete(record.id)"
              >
                <a>删除</a>
              </a-popconfirm>
            </a-menu-item>
          </a-menu>
        </a-dropdown>
      </span>
    </a-table>
    <site-model
      ref="modalForm"
      @ok="modalFormOk"
      @reloadUi="reloadUi"
    ></site-model>
    <a-modal
    :width="850"
    :visible="preVisible"
    @ok="handleOkPre"
    @cancel="handleCancelPre"
    cancelText="关闭"
  >
      <a-form>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-col :span="24">
            <a-form-model-item label="选择类型">
              <a-radio-group  button-style="solid" v-model="factoryType">
                <a-radio-button :value=0 style="width:100px;text-align: center;">
                工  厂
                </a-radio-button>
                <a-radio-button :value=1 style="width:100px;text-align: center;" :disabled="this.fid.length==0?true:false">
                车  间
                </a-radio-button>
              </a-radio-group>
            </a-form-model-item>
          </a-col>
          </a-col>
        </a-row>
      </a-form>
    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancelPre"
      >
        关闭
      </a-button>
      <a-button
        @click="handleOkPre"
        type="primary"
      >确定</a-button>
      <!-- icon="save" -->
    </template>

  </a-modal>
  </a-card>
  
</template>

<script>
import { requestPut } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import SiteModel from './SiteModel'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { deleteAction, getAction, postAction } from '../../../../api/manage'

export default {
  name: 'SiteList',
  mixins: [JeecgListMixin],
  components: {
    SiteModel,
    JInput,
    JEllipsis,
  },
  props: {
    nodeSelected: {
      type: Object,
      default: {}
    }
  },
  data() {
    return {
      //默认排序
      factoryType:0,
      preVisible:false,
      uid:'',
      eid:'',
      fid:'',
      isorter: {
        column: 'num',
        order: 'asc',
      },
      dataSource:[],
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '工厂要素编码',
          align: "center",
          dataIndex: 'code',
          scopedSlots: {
            customRender: 'code',
          },
          sorter: true,
          width:130
        },
        {
          title: '工厂要素名称',

          align: "center",
          dataIndex: 'name',
          scopedSlots: {
            customRender: 'name',
          },
          sorter: true,
          width:150
        },
        {
          title: '责任组织',
          align: 'center',
          dataIndex: 'departName',
          scopedSlots: {
            customRender: 'departId',
          },
          width: 150,
        },
        {
          title: '上级要素',
          align: 'center',
          dataIndex: 'parentName',
          scopedSlots: {
            customRender: 'parentId',
          },
          width: 100,
        },
        {
          title: '要素类型',
          align: 'center',
          dataIndex: 'factoryElementCategoryName',
          scopedSlots: {
            customRender: 'factoryElementCategoryId',
          },
          width: 100,
        },
        {
          title: '是否虚拟',
          align: "center",
          dataIndex: 'virtualFlag',
          scopedSlots: {
            customRender: 'virtualFlag',
          },
          customRender:function(text){
                      if(text==1){
                        return "是";
                      }else{
                        return "否";
                      }
          },
          width: 100,
        },
        {
          title: '创建人',
          align: "center",
          dataIndex: 'createBy',
          scopedSlots: {
            customRender: 'createBy',
          },
          width: 100,
        },
        {
          title: '创建时间',
          align: "center",
          dataIndex: 'createTime',
          scopedSlots: {
            customRender: 'creatTime',
          },
          width: 100,
        },
        {
          title: '修改人',
          align: "center",
          dataIndex: 'updateBy',
          scopedSlots: {
            customRender: 'updateBy',
          },
          width: 100,
        },
        {
          title: '修改时间',
          align: "center",
          dataIndex: 'updateTime',
          scopedSlots: {
            customRender: 'updateTime',
          },
          width: 100,
        },
        {
            title: '操作',
            dataIndex: 'action',
            align:"center",
            scopedSlots: { customRender:'action'},
          width:100
        }
      ],
      url: {
        list: "/base/factoryModel/list",
        delete: "/base/factoryModel/delete",
        deleteBatch: "/base/factoryModel/deleteBatch",
        listByEid:"/base/factoryModel/listByEid"
      },
    };
  },
  methods: {
    loadData([fid,eid]){
      this.fid=fid;
      this.eid=eid;
      this.loading=true;
      if(this.fid&&this.fid!=''){
          let ids=[fid+''];
          postAction(this.url.list,ids).then((res)=>{
            this.dataSource = res.result;
          }).finally(res=>{
            this.loading=false;
          }).finally(res=>{
            this.$refs.modalForm.eid=this.eid;
            this.$refs.modalForm.fid=this.fid;
          })
      }
      else{
          getAction(this.url.listByEid+"/"+this.eid).then(res=>{
            this.dataSource=res.result;
          }).finally(res=>{
            this.loading=false;
          }).finally(res=>{
            this.$refs.modalForm.eid=this.eid;
            this.$refs.modalForm.fid=this.fid;
          })
      }
      
    },
   reloadUi([fid,eid]){
    this.fid=fid;
    this.eid=eid;
    this.loadData([this.fid,this.eid]);
    this.factoryType=0;
    this.$emit('reloadUi',[this.fid,this.eid]);
   },
   clearSelectList(){
    this.selectedRowKeys=[];
   },
    queryTreeTable(){
    
    },

    getCheckboxProps(record) {
      
    },

    //禁用状态样式
    tableRowClass(record, index) {
    
    },

    handleActive(id) {
  
    },

    searchReset() {
  
    },
    handleCancelPre(){
      this.preVisible=false;
    },
    handleOkPre(){
      this.$refs.modalForm.factoryType=this.factoryType;
      this.preVisible=false;
      this.handleAdd();
    },
    handleAddPre(){
      this.preVisible = true;

    },
    handleDelete(id){
      deleteAction(this.url.delete,{id:id}).then(res=>{
              if(res.success){
                this.$message.success(res.message);
              }
              else{
                this.$message.error(res.message);
              }
      }).finally(res=>{
        this.reloadUi([this.fid,this.eid]);
      })
    //  this.$emit('leftNew1',this.eid);
    //  this.$emit('rightNew1',this.fid)
    },
    batchDel(){
      if (this.selectedRowKeys.length <= 0) {
        this.$message.warning('请选择一条记录！');
        return;
      } else {
        var ids = "";
        for (var a = 0; a < this.selectedRowKeys.length; a++) {
          ids += this.selectedRowKeys[a] + ",";
        }
        var that = this;
        this.$confirm({
          title: "确认删除",
          content: "是否删除选中数据?",
          onOk: function () {
            that.loading = true;
            deleteAction(that.url.deleteBatch, {ids: ids}).then((res) => {
              if (res.success) {
                //重新计算分页问题
                that.reCalculatePage(that.selectedRowKeys.length)
                that.$message.success(res.message);
                that.reloadUi([that.fid,that.eid]);
                that.onClearSelected();
              } else {
                that.$message.warning(res.message);
              }
            }).finally(() => {
              that.loading = false;
            });
          }
        });
      }
    },
   
  },
  watch: {
    alterFlag() {
    },
    nodeSelected() {
    }
  },
  created() {
  }
}
</script>
<style>
@import '~@assets/less/common.less';

.frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.notShow{
  display: none
}
</style>